edit

package
v0.0.0-...-2e3bce1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 24, 2026 License: Apache-2.0 Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IcebergTablePaths

func IcebergTablePaths(dataProductPath string) ([]string, error)

IcebergTablePaths finds Iceberg table directories inside a built SAL data product.

func RewriteIcebergMetadataPath

func RewriteIcebergMetadataPath(tablePath string, oldPath string, newPath string) (int, error)

RewriteIcebergMetadataPath updates references to one metadata file path inside Iceberg metadata files.

func RewriteIcebergTableRoot

func RewriteIcebergTableRoot(tablePath string, newRoot string) (int, error)

RewriteIcebergTableRoot updates Iceberg metadata files so a copied table can be read from newRoot.

Types

type EditCmd

type EditCmd struct {
	NewTableRoot string `arg:"--new-table-root" help:"rename the root path of the SAL data product"`
}

func (*EditCmd) Run

func (cfg *EditCmd) Run() error

Jump to